'use strict';

/*
 * controllers/profile/main.js
 * controller for the profile page
 *
 * (c) 2014 Vincent Maliko http://frnchnrd.com
 * License: MIT
 */

angular.module('controllers.clan', ['ngCordova.plugins.camera'])

    .controller('ClanCtrl', [
        '$http',
        '$q',
        '$cordovaCamera',
        '$ionicActionSheet',
        '$ionicModal',
        '$ionicLoading',
        '$ionicPopup',
        '$timeout',
        '$scope',
        '$state',
        '$stateParams',
        'Constants',
        'AuthService',
        function($http,$q,$cordovaCamera, $ionicActionSheet, $ionicModal, $ionicLoading, $ionicPopup, $timeout, $scope,$state, $stateParams, Constants, AuthService) {
            //show loading gif
            $ionicLoading.show({
                template: 'Loading clan...'
            });


            if(Constants.DEBUGMODE){
                console.log("ProfileCtrl controller");
                console.log($stateParams);
            }
            $http.defaults.headers.common['X-Access-Token'] = window.localStorage.getItem('sessionToken') || "";

            // putting the current authenticated user in the $scope.user
            $scope.clan = { public_clan: 1, public_wars: 1, public_stats: 1,name:"",tag:"",password:""};
            $scope.clans = [];
            $scope.joinClanInfo = { };
            $scope.checkUrl = function(url){
                if(url.indexOf('http') === -1){
                    //console.log(url);
                    return "http://" + url;
                }
                else {
                    return url;
                }
                return "asd";
            }
            if(typeof analytics !== 'undefined'){
                analytics.trackView("Clan");
            }

            $scope.joinClan = function(){
                if(Constants.DEBUGMODE){
                    console.log("Join Clan...");
                }

                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    $scope.joinClanInfo.message=response.message;
                    var userData = window.localStorage.getItem('app_user');
                    if(typeof(userData) === "string")
                    {
                        userData = JSON.parse(userData);
                    }
                    angular.extend(userData, response.payload);
                    AuthService.updateUser(userData,{set:true});
                    $scope.closeEdit();
                    $state.go('app.clan');
                    deferred.resolve(response.payload);
                }

                // error callback
                var error = function(error, status, headers, config){
                    $scope.joinClanInfo.message=error.message;
                    $scope.joinClanInfo.password="";

                    deferred.reject(error);
                }

                $http.post(Constants.API.baseUrl+'/clan/join', $scope.joinClanInfo).success(success).error(error);

                return deferred.promise;
            }

            $scope.searchClan = function(){
                if(Constants.DEBUGMODE){
                    console.log("Search Clan...");
                }

                var self = this;
                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    $scope.msg = response.message;
                    $scope.clans=response.payload;
                    deferred.resolve(response.payload);
                }

                // error callback
                var error = function(error, status, headers, config){
                    $scope.clans=[];

                    deferred.reject(error);
                }

                $http.post(Constants.API.baseUrl+'/clan/search', $scope.clan).success(success).error(error);

                return deferred.promise;

            }

            //register Clan
            $scope.registerClan = function(){

                var success = function(response){
                    if(Constants.DEBUGMODE){
                        console.log("Create clan successful");
                        console.log(response);
                    }
                    $ionicLoading.hide();


                };

                var error = function(error){
                    $ionicLoading.hide();

                    $scope.error = error;

                    var errorPopup = $ionicPopup.show({
                        templateUrl: 'templates/modal/error.html',
                        title: 'Error',
                        scope: $scope,
                        buttons: [
                            { text: 'Ok' }
                        ]
                    });

                    errorPopup.then(function(res) {
                        if(Constants.DEBUGMODE){
                            console.log('popup ok Tapped!', res);
                        }
                    });

                    $timeout(function() {
                        errorPopup.close(); //close the popup after 3 seconds for some reason
                    }, 3000);
                };
                //console.log($scope.clan);
                if(!$scope.clan.name || !$scope.clan.password || !$scope.clan.tag){
                    error({'message':'All fields are required!'});
                    return false;
                };

                $ionicLoading.show({
                    template: 'Loading....'
                });

                register($scope.clan).then(success,error);
            }


             function register(userData){
                 var self = this;
                 var deferred = $q.defer();

                 // success callback
                 var success = function(response, status, headers, config){
                 if(Constants.DEBUGMODE){
                     console.log("Clan register success callback");
                     console.log(response);

                 }
                     var userData = window.localStorage.getItem('app_user');
                     if(typeof(userData) === "string")
                     {
                         userData = JSON.parse(userData);
                     }
                     angular.extend(userData, response.payload);
                     AuthService.updateUser(userData,{set:true});
                     $state.go('app.clan');

                 deferred.resolve(response.payload);
                 }

                 // error callback
                 var error = function(error, status, headers, config){
                 if(Constants.DEBUGMODE){
                 console.log("AuthService.error callback function ");
                 console.log(error);
                 }

                 deferred.reject(error);
                 }

                 $http.post(Constants.API.baseUrl+'/clan/create', $scope.clan).success(success).error(error);

                 return deferred.promise;
             };



            //data for the form
            $scope.updateData = angular.copy($scope.clan);
            $scope.$on('event:auth-loginRequired', function() {
                $ionicLoading.hide();
                $scope.modal.hide();
            });

            // Create the login modal that we will use later
            $ionicModal.fromTemplateUrl('templates/clan/join.html', {
                scope: $scope
            }).then(function(modal) {
                $scope.modal = modal;
            });



            // Triggered in the login modal to close it
            $scope.closeEdit = function(saved) {
                if(!saved){
                    //angular.copy($scope.updateData, $scope.clan);
                }

                $scope.modal.hide();
            };

            // Open the edit modal
            $scope.openEdit = function() {
                $scope.modal.show();
            };

            

            $scope.goTo = function(state){
                var self = this;
                if(state === 'join'){
                    $scope.joinClanInfo=self.c;
                    // $scope.joinClanInfo.id=self.c.id;
                    // $scope.joinClanInfo.name=self.c.name;
                    // $scope.joinClanInfo.tag=self.c.tag;

                    $scope.openEdit();
                }else{

                }
            }

            $scope.updateLoading = function(msg,cb){
                $ionicLoading.show({
                    template: msg
                });

                $timeout(function() {
                    $ionicLoading.hide();
                    if(typeof cb === 'function'){
                        cb();
                    }
                }, 2000);
            }

            $scope.updateClan = function(){
                if(Constants.DEBUGMODE){
                    console.log("Update clan : "+$scope.updateData);
                }

                $ionicLoading.show({
                    template: 'Updating clan...'
                });

                var success = function(response){
                    $ionicLoading.hide();

                    $scope.updateLoading('Update successful',function(){
                        AuthService.updateUser($scope.user, {set: true});
                        $scope.closeEdit(true);
                    });
                }

                var error = function(error){
                    $scope.updateLoading('Update Error, please try again '+error.message);
                }
                /*
                 if image changed create a new image then destroy the other one
                 then update the user's info
                 */
                AuthService.currentClan.update().then(success,error);
            }

            


            $scope.$on("$destroy", function() {
                if(Constants.DEBUGMODE){
                    console.log('destroying ProfileCtrl');
                }


            });

            $ionicLoading.hide();
        }]);