'use strict';

/*
 * controllers/profile/main.js
 * controller for the profile page
 *
 * (c) 2014 Vincent Maliko http://frnchnrd.com
 * License: MIT
 */

angular.module('controllers.news', [])

    .controller('NewsCtrl', [
        '$http',
        '$q',
        '$ionicActionSheet',
        '$ionicModal',
        '$ionicLoading',
        '$ionicPopup',
        '$timeout',
        '$scope',
        '$state',
        '$stateParams',
        'Constants',
        'AuthService',
        function($http,$q, $ionicActionSheet, $ionicModal, $ionicLoading, $ionicPopup, $timeout, $scope,$state, $stateParams, Constants, AuthService) {
            //show loading gif
            $ionicLoading.show({
                template: 'Loading...'
            });

            if(Constants.DEBUGMODE){
                console.log("News controller");
                console.log($stateParams);
            }
            $http.defaults.headers.common['X-Access-Token'] = window.localStorage.getItem('sessionToken') || "";

            if(typeof analytics !== 'undefined'){
                analytics.trackView("News Page");
            }

            $scope.news = [];
            $scope.appVersion = appVersion;
            $scope.toDate = function(dateString) {
                return new Date(dateString);
            }
            
            $scope.getNews = function(){
                var deferred = $q.defer();
                $ionicLoading.show({
                    template: 'Loading war stats...'
                });

                var success = function(response, status, headers, config){
                    $scope.news= response;
                    $ionicLoading.hide();
                    deferred.resolve(response.payload);
                }

                // error callback
                var error = function(error, status, headers, config){
                    $scope.title= error.message;
                    $ionicLoading.hide();

                    deferred.reject(error);
                }
                $scope.user = AuthService.currentUser.info;
                $http.get(Constants.API.baseUrl+'/news/'+$scope.appVersion).success(success).error(error).finally(function() {
                    // Stop the ion-refresher from spinning
                    $scope.$broadcast('scroll.refreshComplete');
                });

                return deferred.promise;

            }();
            
            

            $scope.$on("$destroy", function() {
                if(Constants.DEBUGMODE){
                    console.log('destroying ProfileCtrl');
                }


            });
            $ionicLoading.hide();
            // Translation stuff
/*
            String.prototype.ucfirst = function()
            {
                return this.charAt(0).toUpperCase() + this.substr(1);
            }

            var translation = [
            "Liderul",
"Co-lider",
"Liderul",
"Bătrân",
"Membru",
"Trage pentru a reîmprospăta...",
"da",
"nu",
"Spate",
"Închide",
"Trimite",
"Sunteţi sigur că doriţi să {{acţiune}} {{name}}?",
"Vezi profilul",
"Salvaţi",
"Elimina anunţurile",
"Salvate",
"Puterea de atac",
"Restabili cumpărare",
"Instrument de clanul dumneavoastră",
"Plan de război pentru clash este cererea dumneavoastră pentru a vă ajuta să gestionaţi clan în război.",
"Planul strategia ta de război de clan. faceti rezervare. face sugestii. încărcaţi imagini inamicul de baza. câştigat războaie.",
"Vizitaţi site-ul:",
"Acest site-ul web/cerere nu este afiliat cu, aprobat, sponsorizat, sau special aprobat de supercell. supercell nu este responsabil pentru funcționarea sau conținutul de acest site/aplicaţie. utilizaţi mărcile comerciale şi alte de proprietate intelectuală de supercell este doar ca permis în mod expres ca set mai departe în supercell pe fan site-ul kit de acord situat la http://www.supercell.net/terms-of-service. Ciocnirea de clanuri şi logo-urile sale sunt mărci comerciale ale supercell © 2012 supercell",
"conectează-te",
"Conectează-te cu facebook",
"înscrie-te",
"Înscrie-te cu facebook",
"Sau e-mail",
"Parola",
"Nume de utilizator",
"Coc nickname",
"E-mail",
"Ai uitat parola?",
"Videoclipuri",
"Pagina",
"Clanul",
"Război",
"Împinge mesaje",
"Du-te la site-ul",
"Faceţi Sign out",
"Crearea clanului",
"Se alăture clanul",
"Spate",
"ajutor",
"Persoană de contact",
"Arhiva de război",
"Stiri",
"Profilul",
"Editeaza profil",
"Nume de utilizator",
"Profilul public",
"Primi notificări",
"da",
"nu",
"Ex. război începe, clanul mesaje, app actualizări",
"Ciocnire clanuri Nickname",
"Poza de profil schimbarea",
"Chat-ul",
"Nou război",
"Rezervare nouă",
"Membru virtuale",
"Adauga virtuale membru",
"Combina jucători",
"Editați clan",
"Modifica banner-ul de clanului 728 x 90",
"Promovarea",
"Retrogradare",
"Lovi cu piciorul",
"Cautare clan",
"Alăturaţi-vă un clan",
"Caută clan dumneavoastră şi să se alăture it.",
"Căutare",
"Numele Clan sau clan tag-ul",
"Clanul {{clanname}}",
"Clanul",
"Chat-ul",
"Mai multe mesaje",
"Alte",
"Mesaj...",
"Crearea clanului",
"Şi au alături de colegii tai clanul",
"Numele Clan",
"Clan tag-ul",
"Clanul parola",
"Profilul public",
"Războaie publice",
"Statistici publice",
"Site-ul",
"Clanul Descriere",
"Regulile clanului",
"Alăturaţi-vă acestui clan",
"Clanul mesaj",
"Clanul mesaje",
"Clanul voturi sondaj",
"Creaţi un poll vot",
"Vot",
"Clanul busteni",
"Nou sondaj de vot",
"Vă rugăm să folosiţi site-ul făcând clic pe link-ul 'du-te la site-ul'.",
"Această caracteristică este în curs de dezvoltare pentru app mobil.",
"Va multumim pentru intelegere",
"Clanul membru",
"Al doilea război rezultatele",
"Război",
"Jucător",
"Rezultatul",
"Data",
"Trimite push notificare",
"Bătrân, lider si co-lider poate trimite doar notificările împinge. aveţi posibilitatea să trimiteţi un mesaj la fiecare 2 minute",
"Scrieþi mesajul",
"Părăsească clanul",
"Sunteţi sigur că doriţi să părăsească clanul tau? Dacă sunteţi proprietarul clanului (liderul) această acţiune va şterge, de asemenea, clanul excepţia cazului în care se transfera dreptul de proprietate în primul rând.",
"Eroare de reţea",
"Nu a putut conecta la internet vă rugăm să verificaţi conexiunea la reţea",
"Membru",
"Rezerva pentru",
"Începe războiul",
"Sfârşitul războiului",
"Inamicul nr. {{nr}}",
"Sugerează atac",
"Sugestie Vezi {{name}}",
"Imagine",
"Rezerva",
"Atac de stabilit informaţii",
"Rezerva de revocare",
"Vă atac",
"Fără rezerve în acest moment",
"Rezervari:",
"Inamic comentariu",
"Selectaţi setările de război",
"Inamic nume",
"Tag-ul inamice",
"Regulile de război",
"Războiul începe",
"Rezervari / membru",
"1 rezervă timp",
"2 timp de rezervă",
"Rezerva 3 stele",
"Vigoare feedback-ul?",
"Imagini inamice?",
"Membri",
"trupele {{name}}",
"Nivel {{nivelul}}",
"Max: {{max}}",
"Sugerează strategia împotriva jucător {{enemyid}}",
"Castelul capacitate",
"Armata",
"Vrăji",
"Face adăugând info",
"Sfârşitul războiului curent",
"Inamic scor:",
"Sfârşitul războiului, arhivă şi setaţi inamic scor la:",
"Sfârşitul războiului şi a şterge",
"Membru anulează rezervarea",
"Informaţii de atac membru stabilit",
"1 stea",
"2 stele",
"3 stele",
"Nici stele",
"Nu atacat",
"Statistici",
"Război informaţii",
"Război statistici",
"Numărul de războaie",
"Numărul de atac rezultatul introdus de utilizator",
"Stele totală, acumulată în războaie",
"Numarul de rezervari",
"Atac poziţia medie",
"Numărul mediu de stele în atac",
"Jucător scor",
"Colonelul",
"Capitanul",
"Recrut",
"Jucători inamic atac vs",
"Jurnalele de război",
"Notă",
"Pentru scor mai bun vă rugăm să actualizaţi armata şi vrăji, şi au membrii clanului face acelaşi lucru.",
"Formular de contact",
"nume",
"E-mail",
"Mesajul",
"Trimite un e-mail la dezvoltator, dacă aveţi orice probleme sau sugestii.",
"Completaţi numele tau, e-mail şi mesajul.",
"Vă rugăm să scrie în limba engleză, dacă este posibil",
"Scor",
"Tag-ul inamice",
"Armata / vrăji",
"Actualiza armata, vrăji şi capacitate",
"Actualizare armata şi vrăji",
            ];

            // For outputing english values
            // _.forEach(langEn, function(value, key){
            //     if(_.isObject(value)){
            //         _.forEach(value, function(v, k){
            //             document.write("<br/>"+v.toLowerCase().ucfirst());
            //         });
            //     }else{
            //         document.write("<br/>"+value.toLowerCase().ucfirst());
            //     }
            // });

            // After translation to remake the jsonobj
            window.langPt = {};
            var c = 0;
            _.forEach(langEn, function(value, key){
                if(_.isObject(value)){
                    _.forEach(value, function(v, k){
                        //document.write("<br/>"+v);
                        if(_.isEmpty(langPt[key])){
                            langPt[key] = {};
                        }
                        langPt[key][k] = translation[c];
                        c++;
                    });
                }else{
                    langPt[key] = translation[c];
                    c++;
                    //document.write("<br/>"+value);
                }
            });
            document.write(JSON.stringify(langPt));
            /*
            */

        }]);