'use strict';

/*
 * controllers/profile/main.js
 * controller for the profile page
 *
 * (c) 2014 Vincent Maliko http://frnchnrd.com
 * License: MIT
 */

angular.module('controllers.profile', ['ngCordova.plugins.camera','admobModule'])

.controller('ProfileCtrl', [
	'$cordovaCamera',
	'$ionicActionSheet',
	'$ionicModal',
	'$ionicLoading',
	'$ionicPopup',
	'$timeout',
	'$scope',
	'$state',
	'$stateParams',
	'Constants',
	'AuthService',
  'admobSvc',
function($cordovaCamera, $ionicActionSheet, $ionicModal, $ionicLoading, $ionicPopup, $timeout, $scope,$state, $stateParams, Constants, AuthService, admobSvc) {
	//show loading gif
	$ionicLoading.show({
    	template: 'Loading profile...'
   	});
   	
	if(Constants.DEBUGMODE){
		console.log("ProfileCtrl controller");
		console.log($stateParams);
	}
    if(typeof analytics !== 'undefined'){
        analytics.trackView("Profile Page");
    }
	
	// putting the current authenticated user in the $scope.user
	$scope.user = AuthService.currentUser.info;
	
/*	if(AuthService.currentUser.info.avatar === ""){
		$scope.user.avatar = Constants.IMG.avatar;
	}

	if(AuthService.currentUser.info.profileBg === ""){
		$scope.user.profileBg = Constants.IMG.profile_bg;
	}*/
	
	//data for the form
	$scope.updateData = angular.copy($scope.user);

	// Create the login modal that we will use later
	$ionicModal.fromTemplateUrl('templates/profile/edit.html', {
	    scope: $scope
	}).then(function(modal) {
		$scope.modal = modal;
	});

	$scope.$on('event:auth-loginRequired', function() {
		$ionicLoading.hide();
    	$scope.modal.hide();
  	});

	// Triggered in the login modal to close it
	$scope.closeEdit = function(saved) {
	  if(!saved){
	  	angular.copy($scope.updateData, $scope.user);
	  }

	  $scope.modal.hide();
	};

	// Open the edit modal
	$scope.openEdit = function() {
	  $scope.modal.show();
	};

	$scope.goTo = function(state){
		if(state === 'edit'){
			$scope.openEdit();
		}else{
			//console.log("clicked on state : "+state);
		}
	}

	$scope.updateLoading = function(msg,cb){
		$ionicLoading.show({
	    	template: msg
	   	});			

		$timeout(function() {
			$ionicLoading.hide();
			if(typeof cb === 'function'){
				cb();
			}
		}, 2000);
	}

	$scope.removeNotif = function(){
		if($scope.user.android_notif == 0) {
			$scope.user.notif_chat = 0;
			$scope.user.notif_createWar = 0;
			$scope.user.notif_reservation = 0;
		}else {
			$scope.user.notif_chat = 1;
			$scope.user.notif_createWar = 1;
			$scope.user.notif_reservation = 1;			
		}
		console.log($scope.user);
	}

	$scope.updateUser = function(){
		if(Constants.DEBUGMODE){
			console.log("Update user : "+$scope.updateData);
		}
		
		$ionicLoading.show({
	    	template: 'Updating profile...'
	   	});

    var success = function(response){
    	$ionicLoading.hide();	

    	$scope.updateLoading('Update successful',function(){
    		AuthService.updateUser($scope.user, {set: true});
    		$scope.closeEdit(true);	
    	});
		}

		var error = function(error){
			$scope.updateLoading('Update Error, please try again '+error.message);
		}
		/*
			if image changed create a new image then destroy the other one
			then update the user's info
		*/
		AuthService.currentUser.update().then(success,error);
	}

	/* Select image from phone */
	$scope.GetImg = function () {
			var options = {
        quality: 80,
        destinationType: Camera.DestinationType.FILE_URI,
        sourceType: Camera.PictureSourceType.PHOTOLIBRARY,
        encodingType: Camera.EncodingType.JPEG,
        mediaType: Camera.MediaType.PICTURE,
        targetWidth: 256,
        targetHeight: 256,
        allowEdit: false,
        correctOrientation: true
      };

      $cordovaCamera.getPicture(options).then(function(imageData) {
        $ionicLoading.show({ template: "<ion-spinner class='spinner-energized'></ion-spinner>", noBackdrop: true, duration: 1000 });
        $scope.UploadImg(imageData);
      }, function(err) {
        // error
        alert('Failed because: ' + err);
      });
  };

    /* Upload image to server */
  $scope.UploadImg = function (imageData) {
      var ft = new FileTransfer();
      var options = new FileUploadOptions();
      var serverUrl = "http://clashofclanswarplan.com/en/api/profileimg";
      options.fileKey = 'file';
      options.fileName = imageData.substr(imageData.lastIndexOf('/') + 1);
      options.mimeType = "image/jpeg";
      //options.params =
      options.headers = {'X-Access-Token': window.localStorage.getItem('sessionToken') || ""}
      ft.upload(imageData, serverUrl, onUploadSuccess, onUploadError, options);

      function onUploadSuccess(data) {
          if (typeof analytics !== 'undefined') {
              analytics.trackEvent('Profile', 'Upload Profile Img');
          }

          $ionicLoading.hide();
          // Update user image
          var imgData = JSON.parse(data.response);
          $scope.user.profile_pic = imgData.img;
          
          // Save in the app the new info
          AuthService.updateUser($scope.user, {set: true});
          // Give message that the image has been uploaded
          $ionicPopup.alert({
              title: 'Done',
              template: "Image uploaded"
          });
          $scope.modal.hide();

          
      }

      function onUploadError(error) {
          $ionicLoading.hide();
          $ionicPopup.alert({
              title: 'Error',
              template: "There was an error uploading the image."
          });
      }
  };
  // -- AdColony Reward Video
  $scope.adColonyReward = function() {


  		


	    //if no license key, 2% ad traffic share for dev support.
	    //you can get paid license key: https://cranberrygame.github.io/request_cordova_ad_plugin_paid_license_key
	    //window.adcolony.setLicenseKey("yourEmailId@yourEmaildDamin.com", "yourLicenseKey");

	    
      console.log(admobSvc);
	    //
	    window.adcolony.onFullScreenAdLoaded = function() {
	        //alert('onFullScreenAdLoaded');
	    };  
	    window.adcolony.onFullScreenAdShown = function() {
	        //alert('onFullScreenAdShown');
	    };
	    window.adcolony.onFullScreenAdHidden = function() {
	        //alert('onFullScreenAdHidden');
	    };
	    //
	    window.adcolony.onRewardedVideoAdLoaded = function() {
	        //alert('onRewardedVideoAdLoaded');
	    };  
	    window.adcolony.onRewardedVideoAdShown = function() {
	        //alert('onRewardedVideoAdShown');
	    };
	    window.adcolony.onRewardedVideoAdHidden = function() {
	        //alert('onRewardedVideoAdHidden');
	    };  
	    window.adcolony.onRewardedVideoAdCompleted = function() {
	        //alert('The Reward Video was watched');
          // Set the timer and remove the ADS
        ADSMODULE.setNoAdsTime();
        if( admobSvc != undefined) { 
          admobSvc.destroyBannerView(); 
        }

	    };


  		//window.adcolony.showFullScreenAd();

  		window.adcolony.showRewardedVideoAd();

  		//alert(window.adcolony.loadedFullScreenAd());//boolean: true or false
  		//alert(window.adcolony.loadedRewardedVideoAd());//boolean: true or false

  		//alert(window.adcolony.isShowingFullScreenAd());//boolean: true or false
  		//alert(window.adcolony.isShowingRewardedVideoAd());//boolean: true or false


  }
  // -- Finish AdColony Reward Video

	$scope.$on("$destroy", function() {
  		if(Constants.DEBUGMODE){
  			console.log('destroying ProfileCtrl');
  		}

  		
    });

	$ionicLoading.hide();
}]);;;