'use strict';

/*
 * controllers/users/main.js
 * controller for the user list page
 *
 * (c) 2014 Vincent Maliko http://frnchnrd.com
 * License: MIT
 */
angular.module('controllers.users', ['services.models.collection','services.models.user','ngCordova.plugins.camera'])

.controller('UsersCtrl', [
	'ModelCollection',
	'UserModel',
	'$ionicLoading',
  '$ionicModal',
	'$timeout',
	'$scope',
  '$rootScope',
	'$state',
  '$ionicPopup',
	'$stateParams',
	'Constants',
	'AuthService',
  '$ionicScrollDelegate',
  '$cordovaCamera',
  '$q',
  '$http',
  'admobSvc',
function(ModelCollection ,UserModel, $ionicLoading, $ionicModal, $timeout, $scope,$rootScope,$state,$ionicPopup, $stateParams, Constants, AuthService,$ionicScrollDelegate,$cordovaCamera,$q,$http,admobSvc) {

	if(Constants.DEBUGMODE){
		console.log("UsersCtrl controller");
		console.log($stateParams);
	}
  if(typeof analytics !== 'undefined'){
      analytics.trackView("Clan Page");
  }

	$scope.$on('event:auth-loginRequired', function() {
		$ionicLoading.hide();
  });
  $scope.virtualUser  = {};

  $scope.virtualUser = {realId: '', name: '', 'action': ''};
  $scope.virtualAction = {
    create : function(){
      
      self = this;
      $scope.virtualUser.action = "create";
      var success = function(res) {
        $scope.reloadData();
        $scope.closeVirtual();
      }
      var error = function(err) {
        self.err(err);
      }
      self.web($scope.virtualUser).then(success,error);
    },
    edit:    function(){
      self = this;
      $scope.virtualUser.action = "edit";
      var success = function(res) {
        $scope.reloadData();
        $scope.closeVirtual();
      }
      var error = function(err) {
        self.err(err);
      }
      self.web($scope.virtualUser).then(success,error);
    },
    delete:  function(){
      self = this;
      $scope.virtualUser.action = "delete"
      var success = function(res) {
        $scope.reloadData();
        $scope.closeVirtual();
      }
      var error = function(err) {
        self.err(err);
      }
      self.web($scope.virtualUser).then(success,error);
    },
    morph:  function(){
      self = this;
      $scope.virtualUser.action = "morph"
      var success = function(res) {
        $scope.reloadData();
        $scope.closeVirtual();
      }
      var error = function(err) {
        self.err(err);
      }
      self.web($scope.virtualUser).then(success,error);
    },
    web: function(data) {
      $ionicLoading.show({
                    template: "<ion-spinner></ion-spinner>"
                });
      var deferred = $q.defer();

        var success = function (response, status, headers, config) {
            deferred.resolve(response);
            $ionicLoading.hide();
        }

        var error = function (error, status, headers, config) {
            deferred.reject(error);
            $ionicLoading.hide();
        }

        // since the data is cached maybe it'll be nice to reload new data after a x minutes.
        $http.post(Constants.API.baseUrl + '/clan/virtualcrud',data).success(success).error(error);

        return deferred.promise;
    },
    err: function(err) {
      console.log(err);
    }
  };

  
  // set a modelCollection with the userModel type
  // this way the collection.get call will query api/users
	var modelCollection = new ModelCollection({
		model: UserModel,
    //sub: "users",
		busy: false,
		latestTop: true
	});
  
  // binding the collection to the modelCollection.items array
  // after fetching the items the collection will be updated
  $scope.collection = modelCollection.items;
  //$scope.clan = modelCollection.items[0];
  // loading items from the server
  $scope.loadItems = function(params){
  	return modelCollection.get(params);
  }

  $scope.viewPlayer = function(id){
    $state.go("app.clan_player_info",{id:id});
  }

  $scope.reloadData = function(){
      modelCollection =null;
      var modelCollection = new ModelCollection({
          model: UserModel,
          busy: false,
          latestTop: true
      });
      modelCollection.get({cache:false});
      $scope.collection = modelCollection.items;
      //$scope.clan = modelCollection.items[0];


      $scope.loadItems().then(function(response){
          // close the loading overlay
          $scope.$broadcast('scroll.refreshComplete');
          $ionicLoading.hide();
          $scope.clan.members = response[1];
          $scope.clan.info = response[0];

      }, function(error){
          if(Constants.DEBUGMODE){
              console.log("UsersCtrl couldn't fetch collection items");
          }
          $scope.$destroy();
          AuthService.logout().then(function(){$state.go("app.auth")});
          return $state.go("app.auth");
          $scope.$broadcast('scroll.refreshComplete');
          // close the loading overlay
          $ionicLoading.hide();
      });
  }

  $scope.leaveClan = function(){
      if(Constants.DEBUGMODE){
          console.log("Leaving Clan");

      }
      var success = function(response){
          // if the authentication is successful go to profile view
          if(Constants.DEBUGMODE){
              console.log("Authentication successful")
              console.log(response);
          }

          $state.go('app.profile');




      }
      var error = function(error, status, headers, config){
          if(Constants.DEBUGMODE){
              console.log("Can not leave clan ");
              console.log(error);
          }
          $ionicLoading.show({
              template: error.message
          });

          $timeout(function() {
              $ionicLoading.hide();
              if(typeof cb === 'function'){
                  cb();
              }
          }, 2000);


      }
      AuthService.leaveClan().then(success,error);

  }

    $scope.showConfirm = function(action) {
        var confirmPopup = $ionicPopup.confirm({
            
            template: '<h3>{{"clan.leave_clan_head"|translate}}</h3><p>{{"clan.leave_clan_msg"|translate}}</p>'
        });
        confirmPopup.then(function(res) {
            if(res) {
                $scope.leaveClan();
            } else {

            }
        });
    };

  // TODO not functional right now
  $scope.loadPreviousItems = function(params){
  	var _params = angular.extend(params,{
  		prev: true
  	})
  		
  	return modelCollection.get(params);
  }

  /* Select image from phone */
$scope.GetImg = function () {
      var options = {
        quality: 80,
        destinationType: Camera.DestinationType.FILE_URI,
        sourceType: Camera.PictureSourceType.PHOTOLIBRARY,
        encodingType: Camera.EncodingType.JPEG,
        mediaType: Camera.MediaType.PICTURE,
        targetWidth: 728,
        targetHeight: 90,
        allowEdit: true
      };
      $cordovaCamera.getPicture(options).then(onSuccess, onFail);

      function onSuccess(imageData) {
          //var image = document.getElementById('myImage'.player);
          //image.src = imageData;
          $ionicLoading.show({
              template: "Uploading Image"
          });
          $scope.UploadImg(imageData);
      }

      function onFail(message) {
          alert('Failed because: ' + message);
      }
  };

    /* Upload image to server */
$scope.UploadImg = function (imageData) {
      var ft = new FileTransfer();
      var options = new FileUploadOptions();
      var serverUrl = "http://clashofclanswarplan.com/en/api/clan/banner";
      options.fileKey = 'file';
      options.fileName = imageData.substr(imageData.lastIndexOf('/') + 1);
      options.mimeType = "image/jpeg";
      //options.params =
      options.headers = {'X-Access-Token': window.localStorage.getItem('sessionToken') || ""}
      ft.upload(imageData, serverUrl, onUploadSuccess, onUploadError, options);

      function onUploadSuccess(data) {
          if (typeof analytics !== 'undefined') {
              analytics.trackEvent('Profile', 'Upload Profile Img');
          }

          $ionicLoading.hide(); console.log(data);
          // Update user image
          $scope.reloadData();
          
          // Save in the app the new info
          AuthService.updateUser($scope.user, {set: true});
          // Give message that the image has been uploaded
          $ionicPopup.alert({
              title: 'Done',
              template: "Image uploaded"
          });
          $scope.modal.hide();

          
      }

      function onUploadError(error) {
          $ionicLoading.hide();
          $ionicPopup.alert({
              title: 'Error',
              template: "There was an error uploading the image."
          });
      }
  };

  $ionicLoading.show({
	    template: 'Loading users...'
	});

  //loading and setting the collection
  $scope.loadItems().then(function(response){
    // close the loading overlay
    console.log(response);
    //$scope.clan.info = response[0];
    //$scope.clan.members = response[1];
    checkNoAds(response[0]);
    //console.log(response[0]);
  	$ionicLoading.hide();
  }, function(error){
  	if(Constants.DEBUGMODE){
  		console.log("UsersCtrl couldn't fetch collection items");
  	}

    // close the loading overlay
    $ionicLoading.hide();
  });

  // Create the login modal that we will use later
  $ionicModal.fromTemplateUrl('templates/clan/virtualcrud.html', {
      scope: $scope
  }).then(function(virtualcrud) {
      $scope.virtualcrud = virtualcrud;
  });



  // Triggered in the login modal to close it
  $scope.closeVirtual = function(saved) {
      if(!saved){
          //angular.copy($scope.updateData, $scope.clan);
      }

      $scope.virtualcrud.hide();
  };

  // Open the edit modal
  $scope.openVirtual = function(player) {
      if(player !== 'undefined') {
        $scope.virtualUser = player;
      }else{
        $scope.virtualUser = $scope.$parent.virtualUser ;
      }
      $scope.virtualcrud.show();
      
  };

  function checkNoAds(data){
    if(data.noads == 1){
      ADSMODULE.setNoAds(true);
      ADSMODULE.setNoAdsClan(true);
      $rootScope.noAds = true;
      if( admobSvc != undefined) { admobSvc.destroyBannerView(); }
      $timeout.cancel();
      
    }
    else if(ADSMODULE.getNoAdsClan()){
      if(admobSvc != undefined) {
        admobSvc.createBannerView();
      }
      ADSMODULE.setNoAds(false);
      ADSMODULE.setNoAdsClan(false);

    }

  }

  // $scope.closeModal = closeModal;
  // $scope.showModal = showModal;
  // function showModal(templateUrl) {
  //   $ionicModal.fromTemplateUrl(templateUrl, {
  //     scope: $scope
  //   }).then(function(modal) {
  //     $scope.modalImg = modal;
  //     $scope.modalImg.show();
  //   });
  // };
   
  // function closeModal() {
  //   $scope.modalImg.hide();
  //   $scope.modalImg.remove()
  // };
  // $scope.showImages = showImages;
  // $scope.showImages();

  // function showImages(index) {
  //     $scope.activeSlide = index;
  //     //console.log($scope.activeSlide);
  //     $scope.showModal('templates/modal/clanWarWeight.html');
  // };

  $scope.$on('modal.hidden', function() {
    $scope.virtualUser = {realId: ''};
    
  });
  // Execute action on remove modal
  $scope.$on('modal.removed', function() {
    $scope.virtualUser = {realId: ''};
  });


  $scope.$on("$destroy", function() {
    // garbage collection destroy this object
  	if(Constants.DEBUGMODE){
  		console.log('destroying UsersCtrl');
  	}

  	modelCollection = null;
    $scope.virtualcrud.hide();
  });
  
}]);