'use strict';

/*
 * controllers/profile/main.js
 * controller for the profile page
 *
 * (c) 2014 Vincent Maliko http://frnchnrd.com
 * License: MIT
 */

angular.module('controllers.war', ['ngCordova.plugins.camera','services.war', 'ngSanitize'])

    .controller('WarCtrl', [
        'WarService',
        '$http',
        '$q',
        '$cordovaCamera',
        '$ionicActionSheet',
        '$ionicModal',
        '$ionicLoading',
        '$ionicPopup',
        '$ionicPopover',
        '$timeout',
        '$interval',
        '$scope',
        '$state',
        '$stateParams',
        'Constants',
        'AuthService',
        '$filter',
        function(WarService,$http,$q,$cordovaCamera, $ionicActionSheet, $ionicModal, $ionicLoading, $ionicPopup, $ionicPopover, $timeout, $interval, $scope,$state, $stateParams, Constants, AuthService, $filter) {

            //show loading gif
            $ionicLoading.show({
                template: 'Loading war...'
            });


            if(Constants.DEBUGMODE){
                console.log("WarCtrl controller");
                console.log($stateParams);
            }
            $http.defaults.headers.common['X-Access-Token'] = window.localStorage.getItem('sessionToken') || "";

            // putting the current authenticated user in the $scope.user
            if(typeof analytics !== 'undefined'){
                analytics.trackView("War Page");
            }

            $scope.serverUpUrl = "http://clashofclanswarplan.com/en/api/upload/";
            $scope.reserveId = "";
            $scope.enemies = [];
            $scope.enemy={};
            $scope.enemyScore = 0;
            $scope.war={};
            $scope.warStars = {total: 0};
            
            var defLang = window.localStorage.getItem('defLang') || 'en';
            
            $scope.options = [
                { label: $filter('translate')('war.0star'), value: 0 },
                { label: $filter('translate')('war.1star'), value: 1 },
                { label: $filter('translate')('war.2star'), value: 2 },
                { label: $filter('translate')('war.3star'), value: 3 },
                { label: $filter('translate')('war.na'), value: null }
            ];

            $scope.warSettings =
                {
                    start: [{ label: '24 hours ago', value: -24},{ label: '23 hours ago', value: -23},{ label: '22 hours ago', value: -22},{ label: '21 hours ago', value: -21},{ label: '20 hours ago', value: -20},{ label: '19 hours ago', value: -19},{ label: '18 hours ago', value: -18},{ label: '17 hours ago', value: -17},{ label: '16 hours ago', value: -16},{ label: '15 hours ago', value: -15},{ label: '14 hours ago', value: -14},{ label: '13 hours ago', value: -13},{ label: '12 hours ago', value: -12},{ label: '11 hours ago', value: -11},{ label: '10 hours ago', value: -10},{ label: '9 hours ago', value: -9},{ label: '8 hours ago', value: -8},{ label: '7 hours ago', value: -7},{ label: '6 hours ago', value: -6},{ label: '5 hours ago', value: -5},{ label: '4 hours ago', value: -4},{ label: '3 hours ago', value: -3},{ label: '2 hours ago', value: -2},{ label: '1 hour ago', value: -1},{ label: 'now', value: 0},{ label: '1 hour from now', value: 1},{ label: '2 hours from now', value: 2},{ label: '3 hours from now', value: 3},{ label: '4 hours from now', value: 4},{ label: '5 hours from now', value: 5},{ label: '6 hours from now', value: 6},{ label: '7 hours from now', value: 7},{ label: '8 hours from now', value: 8},{ label: '9 hours from now', value: 9},{ label: '10 hours from now', value: 10},{ label: '11 hours from now', value: 11},{ label: '12 hours from now', value: 12},{ label: '13 hours from now', value: 13},{ label: '14 hours from now', value: 14},{ label: '15 hours from now', value: 15},{ label: '16 hours from now', value: 16},{ label: '17 hours from now', value: 17},{ label: '18 hours from now', value: 18},{ label: '19 hours from now', value: 19},{ label: '20 hours from now', value: 20},{ label: '21 hours from now', value: 21},{ label: '22 hours from now', value: 22},{ label: '23 hours from now', value: 23},{ label: '23 hours from now', value: 24}],
                    name: '',
                    asize: [ 5,10,15,20,25,30,35,40,45,50 ],
                    reserve_max: [{ label: 'Unlimited', value: 0},{ label: '1', value: 1},{ label: '2', value: 2}],
                    reserve_time: [ 0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23 ],
                    reserve_time2: [ 0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23 ],
                    reserve_3star: 0,
                    reserve_after_star: 1,
                    hasImg: 0


                };
            $scope.resetWar = function(){

                $scope.war = {   
                    start: $scope.warSettings.start[24],
                    reserve_max: $scope.warSettings.reserve_max[2],
                    asize:$scope.warSettings.asize[1],
                    reserve_time:$scope.warSettings.reserve_time[0],
                    reserve_time2:$scope.warSettings.reserve_time2[0],
                    reserve_3star:$scope.warSettings.reserve_3star,
                    reserve_after_star:$scope.warSettings.reserve_after_star,
                    hasImg:$scope.warSettings.hasImg
                };
            }
            $scope.resetWar();

            $scope.range =function(input, start, stop, step) {
                start = $filter('filterInt')(start);
                stop = $filter('filterInt')(stop);
                step = $filter('filterInt')(step);
                if (isNaN(start)) {
                    start = 0;
                }
                if (isNaN(stop)) {
                    stop = start;
                    start = 0;
                }
                if (isNaN(step)) {
                    step = 1;
                }
                if ((step > 0 && start >= stop) || (step < 0 && start <= stop)){
                    return [];
                }
                for (var i = start; step > 0 ? i < stop : i > stop; i += step){
                    input.push(i);
                }
                return input;
            };

            //$scope.correctlySelected = $scope.options[4];


            $scope.data = function(){
                var deferred = $q.defer();
                // $ionicLoading.show({
                //     template: 'Loading war ...'
                // });

                var success = function(response, status, headers, config){
                    $scope.enemies = response.payload.enemies;
                    $scope.war = response.payload.war;
                    $scope.clanMembers = response.payload.members;
                    $scope.title=$scope.war.name;

                    var total =0;
                    _.forEach($scope.enemies, function(e){
                        total +=  e.stars;
                    })
                    $scope.warStars.total = total;

                    $ionicLoading.hide();
                    deferred.resolve(response.payload);
                }

                // error callback
                var error = function(error, status, headers, config){
                    $scope.title= error.message;
                    $ionicLoading.hide();
                    $scope.$destroy();
                    AuthService.logout().then(function(){$state.go("app.auth")});
                    return $state.go("app.auth");

                    deferred.reject(error);
                }
                //$scope.user = AuthService.currentUser.info;
                $http.get(Constants.API.baseUrl+'/war').success(success).error(error).finally(function() {
                    // Stop the ion-refresher from spinning
                    $scope.$broadcast('scroll.refreshComplete');
                });

                return deferred.promise;

            }
            $scope.data();
            // load war data

            // Update war page once every 2 min if a war is already started.
            $interval(function(){
                if($scope.enemies && $scope.enemies.length){
                    $scope.data();
                }
            }, 120000);



            $scope.action = function(url, data){
                if(Constants.DEBUGMODE){
                    console.log("Action:" + url + " Eid:" + $scope.enemy.player);
                }

                if(typeof analytics !== 'undefined'){
                    analytics.trackEvent('War', url);
                }
                //console.log(data);



                var deferred = $q.defer();
                //$scope.enemy.setSetStars = $scope.correctlySelected.value;


                var success = function(response, status, headers, config){
                    $scope.enemy.message=response.message;
                    $scope.data();
                    //$scope.enemy= response.payload;
                    $timeout(function() {
                        $scope.closeEdit(1);
                        $scope.enemy.message=''; //close the popup after 3 seconds for some reason
                        setSettings();
                    }, 1000);

                    //angular.extend($scope.enemy, response.payload,true);
                    //angular.extend($scope.enemy.reserve, response.payload.reserve);



                    //$scope.closeEdit();
                    //$state.go('app.clan');
                    deferred.resolve(response.payload);
                }

                // error callback
                var error = function(error, status, headers, config){
                    $scope.enemy.message=error.message;
                    //$scope.joinClanInfo.password="";

                    deferred.reject(error);
                }
                $timeout(function() {

                    $http.post(Constants.API.baseUrl + '/war/' + url, $scope.enemy).success(success).error(error);
                }, 200);

                return deferred.promise;
            }



            //data for the form
            $scope.updateData = angular.copy($scope.war);

            // Create the login modal that we will use later
            $ionicModal.fromTemplateUrl('templates/war/reserve.html', {
                id: '1',
                scope: $scope
            }).then(function(modal) {
                $scope.modal = modal;
            });

            $ionicModal.fromTemplateUrl('templates/war/start.html', {
                id: '2',
                scope: $scope
            }).then(function(modal) {
                $scope.modal2 = modal;
            });

            $scope.$on('event:auth-loginRequired', function() {
                $ionicLoading.hide();
                $scope.modal.hide();
                $scope.modal2.hide();
            });

            $scope.$on('modal.hidden', function() {
               delete $scope.enemy.rfp;
               delete $scope.enemy.message;
            });

            // Triggered in the login modal to close it
            $scope.closeEdit = function(index) {
                if(index == 1) $scope.modal.hide();
                else $scope.modal2.hide();
            };

            // Open the edit modal
            $scope.openEdit = function(index) {
                if(index == 1) $scope.modal.show();
                else $scope.modal2.show();
            };

            $scope.goTo = function(state){
                var self = this;
                if(state === 'reserve'){

                    $scope.enemy = self.enemy;
                    $scope.rfpM = $scope.filterMembers();
                    setSettings();
                    $scope.openEdit(1);
                }else{
                    $scope.resetWar();
                    $scope.openEdit(2);
                }
            }

            function setSettings(){
                $scope.canReserve = true;
                $scope.setStars = false;
                $scope.canCancelReserve = false;
                $scope.enemy.setStars = $scope.options[4];
                angular.forEach($scope.enemy.reserve, function(value, key) {
                    if(value.user_id == $scope.user.objectId){
                        $scope.canReserve = false;
                        $scope.setStars = true;
                        $scope.canCancelReserve = true;
                        if(value.stars != null) $scope.enemy.setStars = $scope.options[value.stars];
                    }
                });
            }



            $scope.updateLoading = function(msg,cb){
                $ionicLoading.show({
                    template: msg
                });

                $timeout(function() {
                    $ionicLoading.hide();
                    if(typeof cb === 'function'){
                        cb();
                    }
                }, 2000);
            }

            $scope.updateWar = function(){
                if(Constants.DEBUGMODE){
                    console.log("Update war : "+$scope.updateData);
                }

                $ionicLoading.show({
                    template: 'Updating war...'
                });

                var success = function(response){
                    $ionicLoading.hide();

                    $scope.updateLoading('Update successful',function(){
                        AuthService.updateUser($scope.user, {set: true});
                        $scope.closeEdit(true);
                    });
                }

                var error = function(error){
                    $scope.updateLoading('Update Error, please try again '+error.message);
                }
                /*
                 if image changed create a new image then destroy the other one
                 then update the user's info
                 */
                AuthService.currentWar.update().then(success,error);
            }

            $scope.startWar = function(){
                if(Constants.DEBUGMODE){
                    console.log("Start war");
                }
                if(typeof analytics !== 'undefined'){
                    analytics.trackEvent('War', 'Start');
                }




                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    $scope.data();
                    $scope.closeEdit(2);
                    $scope.closeEdit(1);

                    //$scope.closeEdit();
                    //$state.go('app.clan');
                    deferred.resolve(response.payload);
                }

                // error callback
                var error = function(error, status, headers, config){
                    $ionicPopup.alert({
                        title: 'Problem',
                        template: error.message
                    });


                    deferred.reject(error);
                }

                $http.post(Constants.API.baseUrl+'/war/start', $scope.war).success(success).error(error);

                return deferred.promise;

            }

            $scope.endWar = function(forceDel,score){
                if(!score) return false;

                //return console.log(score);
                if(Constants.DEBUGMODE){
                    console.log("Stop war");
                }
                if(typeof analytics !== 'undefined'){
                    analytics.trackEvent('War', 'End');
                }
                //$scope.showPopup.close();

                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    $scope.data();
                    $scope.closeEdit(1);
                    $scope.closeEdit(2);
                    //$state.go('app.clan');
                    deferred.resolve(response.payload);
                }

                // error callback
                var error = function(error, status, headers, config){
                    console.log(error);
                    $ionicPopup.alert({
                        title: 'Problem',

                        template: error.message
                    });


                    deferred.reject(error);
                }

                $http.post(Constants.API.baseUrl+'/war/end', {force: forceDel,score: score }).success(success).error(error);

                return deferred.promise;

            }

            $scope.viewProfile = function(id) {
                $scope.closeEdit(1);
                $scope.closeEdit(2);
                $state.go('app.clan_player_info',{id:id});
                // "#/app/clan_player_info/"+r.id;
            }

            $scope.showPopup = function() {

                $scope.returnVal = function(){
                    myPopup.close();
                }

                // An elaborate, custom popup
                var myPopup = $ionicPopup.show({
                    template: '<div class="list"><h3>{{"war.end_curr_war"|translate}}</h3><label class="item item-input"><span class="input-label">{{"war.enemy_score"|translate}}</span><input type="number" ng-model="enemyScore" ng-min="0" ng-max="150"></label>' +
                    '<button class="button button-full button-positive" ng-click="endWar(0,enemyScore);returnVal()">{{"war.archive"|translate}} {{enemyScore}}</button>' +

                    '<button class="button button-full button-positive" ng-click="endWar(1,1);returnVal()">{{"war.delete"|translate}}</button>',
                    //title: "",
                    //subTitle: 'Please use normal things',
                    scope: $scope,
                    buttons: [
                        { text: 'X' },

                    ]
                });
                myPopup.then(function(result){

                });

            };

            $scope.showCancel = function(id) {
               var confirmPopup = $ionicPopup.confirm({
                 title: $filter('translate')('war.cancel_m_reserve'),
                 template: $filter('translate')('site.are_you_sure_x')
               });
               confirmPopup.then(function(res) {
                 if(res) {
                   $scope.cancelMemberReserve(id).then(
                        function(response){
                            $scope.closeEdit(1);
                            $scope.closeEdit(2);
                            $scope.data();
                        },
                        function(error){
                            console.log(error);
                        }
                    )
                 } else {
                   //console.log('You are not sure');
                 }
               });
             };

            $scope.cancelMemberReserve = function(id){
                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    deferred.resolve(response);
                }

                // error callback
                var error = function(error, status, headers, config){
                    deferred.reject(error);
                }

                $http.get(Constants.API.baseUrl+ '/war/cancelreserve/' + id).then(success).then(error);

                return deferred.promise;

            } 


            $scope.showSetMInfo = function(rID,oStars) {
                $scope.setstarsmember = {};
                if(oStars !== null) {
                    oStars = parseInt(oStars);
                    $scope.setstarsmember.value = oStars;
                }else{
                    $scope.setstarsmember.value = null;
                }

                // An elaborate, custom popup
                var myPopup = $ionicPopup.show({
                    template: '<select ng-model="setstarsmember.value" ng-options="opt.value as opt.label for opt in options" style="width: 100%;"> </select>',
                    title: $filter('translate')('war.set_m_info'),
                    
                    scope: $scope,
                    buttons: [
                      { text: 'Cancel' },
                      {
                        text: '<b>Save</b>',
                        type: 'button-positive',
                        onTap: function(e) {
                          $scope.updateMemberAttackInfo(rID,$scope.setstarsmember)
                            .then(
                                function(response){
                                    $scope.closeEdit(1);
                                    $scope.closeEdit(2);
                                    $scope.data();
                                },
                                function(){
                                    alert('Error');
                                }
                            );
                        }
                      }
                    ]
                });
                myPopup.then(function(res) {
                    //console.log('Tapped!', res);
                });

            };

            $scope.updateMemberAttackInfo = function(id,data){
                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    deferred.resolve(response);
                }

                // error callback
                var error = function(error, status, headers, config){
                    deferred.reject(error);
                }

                $http.post(Constants.API.baseUrl+ '/war/updatememberattack/' + id,data).then(success).then(error);

                return deferred.promise;

            } 

            /* Select image from phone */
            $scope.GetImg = function(player){
                var options = {
                    quality: 80,
                    destinationType: Camera.DestinationType.FILE_URI,
                    sourceType: Camera.PictureSourceType.PHOTOLIBRARY,
                    encodingType: Camera.EncodingType.JPEG,
                    mediaType: Camera.MediaType.PICTURE,
                    targetWidth: 960,
                    targetHeight: 720,
                    allowEdit: true
                  };
                  $cordovaCamera.getPicture(options).then(onSuccess, onFail);

                function onSuccess(imageData) {
                    //var image = document.getElementById('myImage'.player);
                    //image.src = imageData;
                    $ionicLoading.show({
                        template: "Uploading Image"
                    });
                    $scope.UploadImg(imageData,player);
                }

                function onFail(message) {
                    alert('Failed because: ' + message);
                }
            };

            /* Upload image to server */
            $scope.UploadImg = function(imageData,player){
                var ft = new FileTransfer();
                var options = new FileUploadOptions();
                var serverUrl = "http://clashofclanswarplan.com/en/api/upload/" + player;
                options.fileKey  = 'file';
                options.fileName = imageData.substr(imageData.lastIndexOf('/')+1);
                options.mimeType = "image/jpeg";
                //options.params =
                options.headers = {'X-Access-Token': window.localStorage.getItem('sessionToken') || ""}
                ft.upload(imageData, serverUrl, onUploadSuccess, onUploadError, options);

                function onUploadSuccess(){
                    if(typeof analytics !== 'undefined'){
                        analytics.trackEvent('War', 'Image Uploaded');
                    }

                    $ionicLoading.hide();
                    $ionicPopup.alert({
                        title: 'Done',
                        template: "Image uploaded"
                    });
                    $scope.modal.hide();
                    $scope.data();
                }

                function onUploadError(){
                    $ionicLoading.hide();
                    $ionicPopup.alert({
                        title: 'Error',
                        template: "There was an error uploading the image."
                    });
                }
            };

            $scope.DelImg = function(id){
                if(Constants.DEBUGMODE){
                    console.log("Start war");
                }
                if(typeof analytics !== 'undefined'){
                    analytics.trackEvent('War', 'ImgDel');
                }




                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    $scope.data();
                    $scope.closeEdit(2);
                    $scope.closeEdit(1);

                    //$scope.closeEdit();
                    //$state.go('app.clan');
                    deferred.resolve(response.payload);
                }

                // error callback
                var error = function(error, status, headers, config){
                    $ionicPopup.alert({
                        title: 'Problem',
                        template: error.message
                    });


                    deferred.reject(error);
                }

                $http.post(Constants.API.baseUrl+'/war/imgdel/'+id, {}).success(success).error(error);

                return deferred.promise;

            }

            $scope.goSuggest = function(id){
                $scope.closeEdit(2);
                $scope.closeEdit(1);
                //$scope.popover.hide();
                $state.go("app.war.suggest",{id:id})
            }

            $scope.goSuggestView = function(id){
                $scope.closeEdit(2);
                $scope.closeEdit(1);
                //$scope.popover.hide();
                $state.go("app.war.suggestview",{id:id})
            }

            

            $scope.openPopover = function($event, player) {
                console.log(player);
                $ionicPopover.fromTemplateUrl('templates/popover.html',{scope:$scope}).then(function(popover) {
                    $scope.popover = popover;
                    $scope.selplayer = player;
                    $scope.popover.show($event);
                });
            }

            $scope.toggleGroup = function(group) {
                if ($scope.isGroupShown(group)) {
                  $scope.shownGroup = null;
                } else {
                  $scope.shownGroup = group;
                }
            };
            
            $scope.isGroupShown = function(group) {
                return $scope.shownGroup === group;
            };

            $scope.filterMembers = function() {
                var result = [];
                var res = _.map($scope.enemy.reserve,'user_id');
                var x = angular.copy($scope.clanMembers);
                result = _.remove(x, function(n) {
                  return _.indexOf(res, n.id) < 0;
                });
                return result;
            }

            $scope.closeModal = closeModal;
            $scope.showModal = showModal;
            function showModal(templateUrl) {
              $ionicModal.fromTemplateUrl(templateUrl, {
                scope: $scope
              }).then(function(modal) {
                $scope.modalImg = modal;
                $scope.modalImg.show();
              });
            };
             
            function closeModal() {
              $scope.modalImg.hide();
              $scope.modalImg.remove()
            };
            $scope.showImages = showImages;

            function showImages(index) {
                $scope.activeSlide = index;
                //console.log($scope.activeSlide);
                $scope.showModal('templates/modal/gallery-zoomview.html');
            };


            $scope.$on("$destroy", function() {
                if(Constants.DEBUGMODE){
                    console.log('destroying WarCtrl');
                }
                $scope.modal.remove();
                $scope.modal2.remove();


            });
            $ionicLoading.show({
                template: 'Loading war...'
            });

            //$ionicLoading.hide();

        }]);