'use.strict'
/*
 * models/clan.js
 * This model represents a clan in the database
 * 
 * (c) 2014 Vincent Maliko http://frnchnrd.com
 * License: MIT
 */

angular.module('services.models.clan',[])

    .factory('ClanModel',['$http','$q', 'Constants',
        function($http, $q, Constants){

            var _urlApi = Constants.API.baseUrl+'/clan';

            var clanModel = function(info){
                this.info = info || {id: null};
                this.url = _urlApi;
            };

            //get /api/clans/:id
            clanModel.prototype.get = function(id){
                var self = this;
                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    //update current info for this clan model
                    angular.extend(self.info,response.payload);
                    deferred.resolve(response.payload);
                };

                var error = function(error, status, headers, config){
                    deferred.reject(error);
                };

                // since the data is cached maybe it'll be nice to reload new data after a x minutes.
                $http.get(this.url+'/'+id, {cache: true}).success(success).error(error);

                return deferred.promise;
            };

            // post /api/clans/
            clanModel.prototype.create = function(){
                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    deferred.resolve(response.payload);
                };

                var error = function(error, status, headers, config){
                    deferred.reject(error);
                };

                $http.post(this.url, {clan : self.info}).success(success).error(error);

                return deferred.promise;
            };

            // put /api/clans/:id
            clanModel.prototype.update = function(){
                var self = this;
                var deferred = $q.defer();

                var success = function(response, status, headers, config){
                    angular.extend(self.info,response.payload);
                    return deferred.resolve(response.payload);
                };

                var error = function(error, status, headers, config){
                    return deferred.reject(error);
                };

                $http.put(this.url+'/'+self.info.id, {clan : self.info}).success(success).error(error);

                return deferred.promise;
            };

            return clanModel;
        }]);